/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WarClassMetadata.java 3253 2008-05-16 12:47:44Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.war.impl;

import org.ow2.util.ee.metadata.common.impl.CommonClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarDeployableMetadata;
import org.ow2.util.ee.metadata.war.api.IWarFieldMetadata;
import org.ow2.util.ee.metadata.war.api.IWarMethodMetadata;
import org.ow2.util.scan.api.metadata.structures.JClass;


/**
 * This class represents the annotation metadata of a Bean.<br>
 * From this class, we can access to all methods of a bean with its associated information.
 * @author Florent Benoit
 */
public class WarClassMetadata extends CommonClassMetadata<IWarClassMetadata, IWarMethodMetadata, IWarFieldMetadata> implements
        IWarClassMetadata {

    /**
     * Logger.
     */
    // private static final Log LOGGER = LogFactory.getLog(WarClassMetadata.class);

    /**
     * Parent meta data.
     */
    private IWarDeployableMetadata warDeployableMetadata = null;

    /**
     * Constructor.
     * @param jClass jClass.
     * @param warDeployableMetadata parent metadata object.
     */
    public WarClassMetadata(final JClass jClass, final WarDeployableMetadata warDeployableMetadata) {
        super(jClass);
        this.warDeployableMetadata = warDeployableMetadata;
    }

    /**
     * @return the archive metadata
     */
    public IWarDeployableMetadata getWarDeployableMetadata() {
        return this.warDeployableMetadata;
    }

    /**
     * Attach clone to deployable metadata.
     * @param warDeployableMetadata the deployable metadata
     * @return the clone
     * @throws CloneNotSupportedException never
     */
    public IWarClassMetadata attachClone(final IWarDeployableMetadata warDeployableMetadata) throws CloneNotSupportedException {
        WarClassMetadata warClassMetadata = (WarClassMetadata) clone();
        warClassMetadata.warDeployableMetadata = warDeployableMetadata;
        return warClassMetadata;
    }

}
