package org.ow2.util.ee.metadata.war.impl.configurator;

import java.util.List;
import java.util.Set;

import org.ow2.util.ee.metadata.common.impl.configurator.CommonClassMetadataConfigurator;
import org.ow2.util.ee.metadata.war.api.IWarClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarFieldMetadata;
import org.ow2.util.ee.metadata.war.api.IWarMethodMetadata;
import org.ow2.util.ee.metadata.war.impl.WarClassMetadata;
import org.ow2.util.ee.metadata.war.impl.WarDeployableMetadata;
import org.ow2.util.ee.metadata.war.impl.specific.ISpecificWarDeployableMetadataConfigurator;
import org.ow2.util.scan.api.configurator.IFieldConfigurator;
import org.ow2.util.scan.api.configurator.IMethodConfigurator;
import org.ow2.util.scan.api.metadata.structures.JClass;
import org.ow2.util.scan.api.metadata.structures.JField;
import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * WarClassMetadataConfigurator.
 * @author Gael Lalire
 */
public class WarClassMetadataConfigurator extends
        CommonClassMetadataConfigurator<IWarClassMetadata, IWarMethodMetadata, IWarFieldMetadata> {

    /**
     * annotationParsingDesactived.
     */
    private boolean annotationParsingDesactived;

    /**
     * WarClassMetadataConfigurator.
     * @param jClass signature
     * @param warArchiveMetadata parent
     * @param annotationParsingDesactived annotationParsingDesactived
     * @param specificWarDeployableMetadataConfiguratorList specificWarDeployableMetadataConfiguratorList
     */
    public WarClassMetadataConfigurator(
            final JClass jClass,
            final WarDeployableMetadata warArchiveMetadata,
            final boolean annotationParsingDesactived,
            final List<ISpecificWarDeployableMetadataConfigurator>
                specificWarDeployableMetadataConfiguratorList) {
        super(new WarClassMetadata(jClass, warArchiveMetadata), specificWarDeployableMetadataConfiguratorList);
        this.annotationParsingDesactived = annotationParsingDesactived;
        if (!annotationParsingDesactived) {
            registerAnnotationVisitor();
        }
    }

    /**
     * @param jField signature
     * @return configurator
     */
    @Override
    protected IFieldConfigurator createFieldMetadataConfigurator(final JField jField) {
        return new WarFieldMetadataConfigurator(jField, getClassMetadata(), annotationParsingDesactived,
                getSpecificClassConfiguratorList());
    }

    /**
     * @param jMethod signature
     * @return configurator
     */
    @Override
    protected IMethodConfigurator createMethodMetadataConfigurator(final JMethod jMethod) {
        return new WarMethodMetadataConfigurator(jMethod, getClassMetadata(), annotationParsingDesactived,
                getSpecificClassConfiguratorList());
    }

    /**
     * add class to archive.
     * @param referencedClasses you may fill this set with class referenced in current metadata
     */
    @Override
    public void configurationComplete(final Set<String> referencedClasses) {
        IWarClassMetadata warClassMetadata = getClassMetadata();
        warClassMetadata.getWarDeployableMetadata().addWarClassMetadata(warClassMetadata);
        super.configurationComplete(referencedClasses);
    }

}
