/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: SpecificWarClassMetadata.java 3600 2008-07-04 15:25:28Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.war.impl.specific;

import java.util.Collection;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.war.api.IWarClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarDeployableMetadata;
import org.ow2.util.ee.metadata.war.api.IWarFieldMetadata;
import org.ow2.util.ee.metadata.war.api.IWarMethodMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificClassMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificFieldMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificMethodMetadata;
import org.ow2.util.scan.api.metadata.specific.SpecificClassMetadata;
import org.ow2.util.scan.api.metadata.structures.JClass;
import org.ow2.util.scan.api.metadata.structures.JField;
import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * You can extends this class to create a specific war class metadata.
 * @param <SC> specific class metadata
 * @param <SM> specific method metadata
 * @param <SF> specific field metadata
 * @author Gael Lalire
 */
public class SpecificWarClassMetadata<
    SC extends ISpecificClassMetadata<SC, SM, SF>,
    SM extends ISpecificMethodMetadata<SC, SM, SF>,
    SF extends ISpecificFieldMetadata<SC, SM, SF>>
        extends SpecificClassMetadata<SC, SM, SF> implements IWarClassMetadata {

    /**
     * The standard war class metadata.
     */
    private IWarClassMetadata warClassMetadata;

    /**
     * Construct delegation.
     * @param warClassMetadata the standard war class metadata.
     */
    protected SpecificWarClassMetadata(final IWarClassMetadata warClassMetadata) {
        this.warClassMetadata = warClassMetadata;
    }

    /**
     * {@inheritDoc}
     */
    public JClass getJClass() {
        return warClassMetadata.getJClass();
    }

    /**
     * {@inheritDoc}
     */
    public void setJClass(final JClass class1) {
        warClassMetadata.setJClass(class1);
    }

    /**
     * {@inheritDoc}
     */
    public IWarClassMetadata attachClone(final IWarDeployableMetadata warDeployableMetadata) throws CloneNotSupportedException {
        return warClassMetadata.attachClone(warDeployableMetadata);
    }

    /**
     * {@inheritDoc}
     */
    public IWarDeployableMetadata getWarDeployableMetadata() {
        return warClassMetadata.getWarDeployableMetadata();
    }

    /**
     * {@inheritDoc}
     */
    public List<IJAnnotationResource> getJAnnotationResources() {
        return warClassMetadata.getJAnnotationResources();
    }

    /**
     * {@inheritDoc}
     */
    public List<IJEjbEJB> getJEjbEJBs() {
        return warClassMetadata.getJEjbEJBs();
    }

    /**
     * {@inheritDoc}
     */
    public List<IJavaxPersistenceContext> getJavaxPersistencePersistenceContexts() {
        return warClassMetadata.getJavaxPersistencePersistenceContexts();
    }

    /**
     * {@inheritDoc}
     */
    public List<IJavaxPersistenceUnit> getJavaxPersistencePersistenceUnits() {
        return warClassMetadata.getJavaxPersistencePersistenceUnits();
    }

    /**
     * {@inheritDoc}
     */
    public void setJAnnotationResources(final List<IJAnnotationResource> annotationResources) {
        warClassMetadata.setJAnnotationResources(annotationResources);
    }

    /**
     * {@inheritDoc}
     */
    public void setJEjbEJBs(final List<IJEjbEJB> ejbEJBs) {
        warClassMetadata.setJEjbEJBs(ejbEJBs);
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistencePersistenceContexts(final List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts) {
        warClassMetadata.setJavaxPersistencePersistenceContexts(javaxPersistencePersistenceContexts);
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistencePersistenceUnits(final List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits) {
        warClassMetadata.setJavaxPersistencePersistenceUnits(javaxPersistencePersistenceUnits);
    }

    /**
     * {@inheritDoc}
     */
    public IJEjbEJB getJEjbEJB() {
        return warClassMetadata.getJEjbEJB();
    }

    /**
     * {@inheritDoc}
     */
    public void setJEjbEJB(final IJEjbEJB ejbEJB) {
        warClassMetadata.setJEjbEJB(ejbEJB);
    }

    /**
     * {@inheritDoc}
     */
    public IJAnnotationResource getJAnnotationResource() {
        return warClassMetadata.getJAnnotationResource();
    }

    /**
     * {@inheritDoc}
     */
    public void setJAnnotationResource(final IJAnnotationResource annotationResource) {
        warClassMetadata.setJAnnotationResource(annotationResource);
    }

    /**
     * {@inheritDoc}
     */
    public IJavaxPersistenceContext getJavaxPersistenceContext() {
        return warClassMetadata.getJavaxPersistenceContext();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isPersistenceContext() {
        return warClassMetadata.isPersistenceContext();
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistenceContext(final IJavaxPersistenceContext javaxPersistenceContext) {
        warClassMetadata.setJavaxPersistenceContext(javaxPersistenceContext);
    }

    /**
     * {@inheritDoc}
     */
    public IJavaxPersistenceUnit getJavaxPersistenceUnit() {
        return warClassMetadata.getJavaxPersistenceUnit();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isPersistenceUnit() {
        return warClassMetadata.isPersistenceUnit();
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistenceUnit(final IJavaxPersistenceUnit javaxPersistenceUnit) {
        warClassMetadata.setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

    /**
     * {@inheritDoc}
     */
    public void addStandardFieldMetadata(final IWarFieldMetadata fieldAnnotationMetadata) {
        warClassMetadata.addStandardFieldMetadata(fieldAnnotationMetadata);
    }

    /**
     * {@inheritDoc}
     */
    public void addStandardMethodMetadata(final IWarMethodMetadata methodAnnotationMetadata) {
        warClassMetadata.addStandardMethodMetadata(methodAnnotationMetadata);
    }

    /**
     * {@inheritDoc}
     */
    public IWarFieldMetadata getStandardFieldMetadata(final JField field) {
        return warClassMetadata.getStandardFieldMetadata(field);
    }

    /**
     * {@inheritDoc}
     */
    public Collection<? extends IWarFieldMetadata> getStandardFieldMetadataCollection() {
        return warClassMetadata.getStandardFieldMetadataCollection();
    }

    /**
     * {@inheritDoc}
     */
    public IWarMethodMetadata getStandardMethodMetadata(final JMethod method) {
        return warClassMetadata.getStandardMethodMetadata(method);
    }

    /**
     * {@inheritDoc}
     */
    public Collection<? extends IWarMethodMetadata> getStandardMethodMetadataCollection() {
        return warClassMetadata.getStandardMethodMetadataCollection();
    }

    /**
     * {@inheritDoc}
     */
    public List<? extends IWarFieldMetadata> searchStandardFieldMetadata(final String fieldName) {
        return warClassMetadata.searchStandardFieldMetadata(fieldName);
    }

    /**
     * {@inheritDoc}
     */
    public List<? extends IWarMethodMetadata> searchStandardMethodMetadata(final String methodName) {
        return warClassMetadata.searchStandardMethodMetadata(methodName);
    }


}
